/**
 * Copyright 2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.log.internal;

import java.text.MessageFormat;

import org.ow2.util.i18n.I18n;
import org.ow2.util.log.Log;

/**
 * A {@code SystemLog} is ...
 *
 * @author Guillaume Sauthier
 */
public class SystemLog implements Log {
    public boolean isDebugEnabled() {
        return false;
    }

    public boolean isErrorEnabled() {
        return true;
    }

    public boolean isFatalEnabled() {
        return true;
    }

    public boolean isInfoEnabled() {
        return true;
    }

    public boolean isTraceEnabled() {
        return false;
    }

    public boolean isWarnEnabled() {
        return true;
    }

    public void trace(Object message, Object... args) {
        // No-op
    }

    public void debug(Object message, Object... args) {
        // No-op
    }

    public void info(Object message, Object... args) {
        System.out.printf("[info] " + message.toString(), args);
    }

    public void warn(Object message, Object... args) {
        System.out.printf("[warn] " + message.toString(), args);
    }

    public void error(Object message, Object... args) {
        System.err.printf("[error] " + message.toString(), args);
    }

    public void fatal(Object message, Object... args) {
        System.err.printf("[fatal] " + message.toString(), args);
    }

    public I18n getI18n() {
        return null;
    }
}
